# rtt

`rtt` is a cli application which allows you to convert a repository of code/files
and webpages into flat files (both `txt` and `md` formats are supported) and
interact with LLMs all using one CLI

## Author

[@shammianand](https://www.github.com/shammianand)
